@@ -30,13 +30,14 @@ const (
 )
 
 type mergePayload struct {
-	repo          ghrepo.Interface
-	pullRequestID string
-	method        PullRequestMergeMethod
-	auto          bool
-	commitSubject string
-	commitBody    string
-	setCommitBody bool
+	repo            ghrepo.Interface
+	pullRequestID   string
+	method          PullRequestMergeMethod
+	auto            bool
+	commitSubject   string
+	commitBody      string
+	setCommitBody   bool
+	expectedHeadOid string
 }
 
 // TODO: drop after githubv4 gets updated
@@ -70,6 +71,11 @@ func mergePullRequest(client *http.Client, payload mergePayload) error {
 		input.CommitBody = &commitBody
 	}
 
+	if payload.expectedHeadOid != "" {
+		expectedHeadOid := githubv4.GitObjectID(payload.expectedHeadOid)
+		input.ExpectedHeadOid = &expectedHeadOid
+	}
+
 	variables := map[string]interface{}{
 		"input": input,
 	}
