@@ -6,6 +6,7 @@ import (
 	"sync"
 
 	"github.com/MakeNowJust/heredoc"
+	"github.com/cli/cli/v2/api"
 	codespacesAPI "github.com/cli/cli/v2/internal/codespaces/api"
 	actionsCmd "github.com/cli/cli/v2/pkg/cmd/actions"
 	aliasCmd "github.com/cli/cli/v2/pkg/cmd/alias"
@@ -57,8 +58,8 @@ func NewCmdRoot(f *cmdutil.Factory, version, buildDate string) *cobra.Command {
 		},
 	}
 
-	cmd.SetOut(f.IOStreams.ErrOut) // command usage summary and deprecation warnings
-	cmd.SetErr(f.IOStreams.ErrOut) // error messages
+	// cmd.SetOut(f.IOStreams.Out)    // can't use due to https://github.com/spf13/cobra/issues/1708
+	// cmd.SetErr(f.IOStreams.ErrOut) // just let it default to os.Stderr instead
 
 	cmd.Flags().Bool("version", false, "Show gh version")
 	cmd.PersistentFlags().Bool("help", false, "Show help for command")
@@ -127,7 +128,14 @@ func bareHTTPClient(f *cmdutil.Factory, version string) func() (*http.Client, er
 		if err != nil {
 			return nil, err
 		}
-		return factory.NewHTTPClient(f.IOStreams, cfg, version, false)
+		opts := api.HTTPClientOptions{
+			AppVersion:        version,
+			Config:            cfg,
+			Log:               f.IOStreams.ErrOut,
+			LogColorize:       f.IOStreams.ColorEnabled(),
+			SkipAcceptHeaders: true,
+		}
+		return api.NewHTTPClient(opts)
 	}
 }
 
